      SUBROUTINE CGLALO (OLDLAT, OLDLON, CGLAT, CGLON)
C-----------------------------------------------------------------------
C
C     THIS SUBROUTINE IS THE HAKURA/GUSTAFSSON COORDINATE TRANSFORMATION
C     OF GEOGRAPHIC LATITUDE AND LONGITUDE TO COORECTED GEOMAGNETIC
C     LATITUDE AND LONGITUDE.
C
C     RE: A REVISED CORRECTED GEOMAGNETIC COORDINATE SYSTEM,
C         KGO REPORT NO. 694 (APRIL 1969), KIRUNA GEOPHYSICAL 
C         OBSERVATORY, S-981 01 KIRUNA 1, SWEDEN. (BASED ON IGRF65
C         MODEL)
C
C     THIS ROUTINE HAS BEEN CORRECTED AND UPDATED BY MAURIZIO CANDIDI
C     AND HERBERT KROEHL OF USDOC/NOAA/DSD, BOULDER, CO 80303.
C     THIS ROUTINE HAS BEEN CORRECTED TO ALLOW CALCULATION OF CGM
C     COORDINATES RIGHT UP TO THE GEOGRAPHIC POLES. RKR 80/02/20.
C                            R. K. ROSICH, USDOC/NTIA/ITS, 79/02/23.
C
C     MODIFIED TO USE ARGUMENTS BASED ON IGRF80 PRESENTED BY GUSTAFSSON
C     AT CHAPMAN CONF.,IRVINGTON,VA, APRIL 83.  DISCONTINUITIES IN HIS
C     TABLE HAVE BEEN REMOVED BY CURVE FITTING.
C           F. J. RICH, A.F. GEOPHYS LAB., BEDFORD, MA 01731 AUG 83 
C
C     GEOMAGNETIC LATITUDE AND LONGITUDE COORDINATES PREVIOUSLY
C     OMITTED IN THE EQUATORIAL REGION BETWEEN +22 DEGREES AND
C     -10 DEGREES GEOGRAPHIC LATITUDE (INCLUSIVE) WERE OBTAINED
C     BY APPLYING A SMOOTH CUBIC REGRESSION ACROSS THE NULL REGION.
C     THIS INTERPOLATION WAS PERFORMED BY RADEX,INC., OCTOBER,1983.
C
C-----------------------------------------------------------------------
C     MODIFIED TO USE ARGUMENTS BASED ON IGRF 2005 MODEL. THE
C     COORDINATES IN THE AREA OF THE SOUTH ATLANTIC ANOMALY AND THE
C     DIP EQUATOR HAVE BEEN FURTHER CORRECTED BY A RESAMPLING OF POINTS
C     BASED ON SMOOTHED DERIVATIVES BETWEEN CG POINTS.
C
C     THIS VERSION DOES NOT CONTAIN THE POLAR TRIANGULATION SCHEME AS
C     SEEN IN EARLIER VERSIONS. AN UPDATED EARLIER VERSION DOES EXIST.
C
C                                  W. HERES, AER INC., AUGUST 2006
C-----------------------------------------------------------------------
C
C     ARGUMENTS:
C        INPUT:
C           OLDLAT = GEOGRAPHIC LATITUDE (DEGREES, +=N, -=S),
C           OLDLON = GEOGRAPHIC LONGITUDE (DEGREES E. LONG.),
C        OUTPUT:
C           CGLAT = CORRECTED GEOMAGNETIC LATITUDE (DEGREES, +=N, -=S),
C           CGLON = CORRECTED GEOMAGNETIC LONGITUDE (DEGREES E. LONG.).
C
C           THE TABLE OF CORRECTED GEOMAGNETIC LATITUDE (2 DEG STEP)
C           AND LONGITUDE (10 DEG STEP) PAIRS IS FOUND IN ARRAY A.
C
C-----------------------------------------------------------------------
C     Updated with points generated from the IGRF2005 model. Based on
C     previous work of C. A. Hein of Radex, Inc.
C
C     UPDATED BY:
C
C     Will Heres
C     AER, Inc.
C     131 Hartwell Avenue
C     Lexington, MA 02421
C     wheres@aer.com
C
C-----------------------------------------------------------------------

      IMPLICIT REAL*8(A-H,O-Z)
      DIMENSION A(2,36,89)

      DATA CGMNLA,CGMNLO/  83.11, 170.15/ CGMSLA,CGMSLO/ -74.07,  18.84/
C 
C
      DATA((A(I,J,  1),I=1,2),J=1,36)/
     $  83.11,152.40, 82.82,153.00, 82.54,154.08, 82.29,155.49,
     $  82.06,157.20, 81.86,159.20, 81.70,161.36, 81.56,163.68,
     $  81.46,166.13, 81.40,168.59, 81.38,171.10, 81.39,173.59,
     $  81.43,176.01, 81.52,178.35, 81.64,180.52, 81.80,182.52,
     $  81.99,184.30, 82.23,185.78, 82.48,186.95, 82.77,187.73,
     $  83.07,188.05, 83.39,187.85, 83.70,187.07, 84.00,185.64,
     $  84.28,183.51, 84.52,180.66, 84.70,177.23, 84.81,173.32,
     $  84.85,169.18, 84.81,165.10, 84.69,161.35, 84.50,158.15,
     $  84.27,155.64, 84.00,153.81, 83.71,152.73, 83.41,152.25/
C
      DATA((A(I,J,  2),I=1,2),J=1,36)/
     $  82.47,136.01, 81.95,138.20, 81.48,140.92, 81.06,144.04,
     $  80.70,147.47, 80.39,151.15, 80.14,155.03, 79.93,159.06,
     $  79.78,163.18, 79.68,167.38, 79.63,171.58, 79.63,175.73,
     $  79.69,179.81, 79.81,183.76, 79.98,187.54, 80.23,191.12,
     $  80.53,194.44, 80.91,197.48, 81.35,200.15, 81.85,202.40,
     $  82.42,204.11, 83.04,205.17, 83.70,205.36, 84.37,204.38,
     $  85.03,201.80, 85.65,197.02, 86.15,189.50, 86.49,179.02,
     $  86.58,166.68, 86.41,154.87, 86.03,145.57, 85.50,139.30,
     $  84.90,135.56, 84.27,133.89, 83.64,133.60, 83.03,134.40/
C
      DATA((A(I,J,  3),I=1,2),J=1,36)/
     $  81.34,123.00, 80.67,126.85, 80.08,131.05, 79.58,135.54,
     $  79.14,140.31, 78.78,145.27, 78.49,150.40, 78.25,155.69,
     $  78.07,161.07, 77.95,166.49, 77.88,171.90, 77.87,177.26,
     $  77.91,182.52, 78.03,187.64, 78.21,192.58, 78.49,197.31,
     $  78.85,201.81, 79.31,206.04, 79.87,210.00, 80.53,213.64,
     $  81.29,216.92, 82.15,219.75, 83.08,222.01, 84.10,223.44,
     $  85.15,223.51, 86.23,221.14, 87.25,213.62, 88.07,194.43,
     $  88.29,159.17, 87.74,130.86, 86.83,118.58, 85.81,114.18,
     $  84.80,113.37, 83.83,114.46, 82.93,116.65, 82.09,119.53/
C
      DATA((A(I,J,  4),I=1,2),J=1,36)/
     $  79.89,113.29, 79.13,118.41, 78.48,123.70, 77.93,129.23,
     $  77.47,134.93, 77.09,140.85, 76.78,146.92, 76.54,153.13,
     $  76.35,159.45, 76.21,165.80, 76.12,172.14, 76.08,178.41,
     $  76.11,184.57, 76.20,190.57, 76.38,196.36, 76.65,201.93,
     $  77.01,207.26, 77.51,212.37, 78.16,217.26, 78.93,221.97,
     $  79.83,226.49, 80.86,230.89, 82.01,235.15, 83.26,239.36,
     $  84.60,243.52, 86.02,247.76, 87.47,252.16, 88.96,258.19,
     $  89.55, 71.16, 88.09, 80.93, 86.66, 85.79, 85.30, 90.20,
     $  84.02, 94.61, 82.83, 99.05, 81.74,103.63, 80.76,108.37/
C
      DATA((A(I,J,  5),I=1,2),J=1,36)/
     $  78.23,106.10, 77.42,112.07, 76.73,118.15, 76.17,124.39,
     $  75.70,130.79, 75.33,137.39, 75.03,144.18, 74.79,151.10,
     $  74.61,158.15, 74.46,165.24, 74.35,172.33, 74.29,179.33,
     $  74.28,186.20, 74.34,192.87, 74.48,199.30, 74.73,205.49,
     $  75.09,211.44, 75.61,217.16, 76.31,222.73, 77.15,228.17,
     $  78.16,233.61, 79.32,239.12, 80.61,244.88, 82.04,251.19,
     $  83.54,258.51, 85.10,268.03, 86.63,282.89, 87.88,312.77,
     $  88.09,  7.49, 87.06, 44.84, 85.64, 62.46, 84.17, 73.15,
     $  82.76, 81.13, 81.44, 87.94, 80.24, 94.19, 79.17,100.18/
C
      DATA((A(I,J,  6),I=1,2),J=1,36)/
     $  76.43,100.68, 75.59,107.22, 74.90,113.83, 74.33,120.58,
     $  73.88,127.48, 73.53,134.61, 73.25,141.93, 73.03,149.43,
     $  72.86,157.07, 72.71,164.79, 72.59,172.50, 72.50,180.14,
     $  72.44,187.62, 72.45,194.86, 72.54,201.76, 72.76,208.40,
     $  73.12,214.77, 73.64,220.92, 74.35,226.94, 75.26,232.91,
     $  76.34,238.97, 77.61,245.25, 79.02,252.02, 80.56,259.68,
     $  82.17,268.90, 83.78,281.01, 85.24,298.69, 86.24,326.06,
     $  86.35,  1.07, 85.51, 30.21, 84.18, 49.26, 82.70, 62.19,
     $  81.22, 71.96, 79.82, 80.09, 78.55, 87.33, 77.41, 94.10/
C
      DATA((A(I,J,  7),I=1,2),J=1,36)/
     $  74.53, 96.48, 73.67,103.39, 72.98,110.33, 72.42,117.34,
     $  72.01,124.70, 71.69,132.29, 71.44,140.10, 71.25,148.10,
     $  71.08,156.25, 70.93,164.47, 70.78,172.68, 70.65,180.79,
     $  70.55,188.70, 70.51,196.34, 70.55,203.68, 70.72,210.71,
     $  71.11,217.46, 71.63,223.99, 72.28,230.38, 73.26,236.64,
     $  74.43,243.10, 75.78,249.92, 77.30,257.36, 78.93,265.86,
     $  80.62,276.09, 82.25,289.25, 83.65,307.16, 84.52,331.21,
     $  84.58,358.86, 83.81, 23.29, 82.53, 41.56, 81.04, 55.04,
     $  79.51, 65.57, 78.06, 74.38, 76.72, 82.20, 75.54, 89.48/
C
      DATA((A(I,J,  8),I=1,2),J=1,36)/
     $  72.52, 93.04, 71.67,100.26, 71.01,107.56, 70.49,115.02,
     $  70.11,122.69, 69.82,130.59, 69.60,138.73, 69.42,147.09,
     $  69.26,155.61, 69.11,164.22, 68.95,172.82, 68.79,181.31,
     $  68.65,189.58, 68.55,197.56, 68.54,205.21, 68.67,212.51,
     $  69.04,219.52, 69.55,226.29, 70.20,232.94, 71.17,239.59,
     $  72.39,246.41, 73.87,253.56, 75.48,261.45, 77.20,270.46,
     $  78.95,281.25, 80.60,294.79, 81.96,312.20, 82.77,333.95,
     $  82.79,357.73, 82.04, 19.36, 80.78, 36.67, 79.27, 50.14,
     $  77.70, 60.97, 76.19, 70.13, 74.81, 78.28, 73.58, 85.84/
C
      DATA((A(I,J,  9),I=1,2),J=1,36)/
     $  70.50, 90.46, 69.67, 97.91, 69.03,105.43, 68.54,113.11,
     $  68.18,121.02, 67.92,129.17, 67.73,137.59, 67.57,146.24,
     $  67.43,155.07, 67.27,164.01, 67.10,172.93, 66.91,181.74,
     $  66.72,190.32, 66.58,198.57, 66.52,206.46, 66.59,213.99,
     $  66.96,221.20, 67.45,228.17, 68.09,235.01, 69.09,241.87,
     $  70.35,248.93, 71.85,256.42, 73.58,264.64, 75.39,274.00,
     $  77.20,285.08, 78.88,298.68, 80.22,315.53, 80.98,335.64,
     $  80.98,357.09, 80.24, 16.88, 78.97, 33.35, 77.44, 46.63,
     $  75.82, 57.55, 74.24, 66.88, 72.79, 75.20, 71.53, 82.95/
C
      DATA((A(I,J, 10),I=1,2),J=1,36)/
     $  68.46, 88.35, 67.64, 95.95, 67.01,103.63, 66.55,111.49,
     $  66.23,119.60, 66.00,127.98, 65.84,136.63, 65.71,145.53,
     $  65.58,154.62, 65.42,163.82, 65.23,173.01, 65.01,182.08,
     $  64.78,190.91, 64.59,199.39, 64.48,207.49, 64.51,215.21,
     $  64.86,222.58, 65.23,229.71, 65.97,236.72, 66.99,243.76,
     $  68.30,251.00, 69.85,258.69, 71.61,267.12, 73.52,276.76,
     $  75.40,288.03, 77.10,301.57, 78.44,317.90, 79.18,336.79,
     $  79.17,356.65, 78.41, 15.17, 77.12, 30.98, 75.54, 44.04,
     $  73.86, 54.95, 72.19, 64.39, 70.74, 72.81, 69.49, 80.71/
C
      DATA((A(I,J, 11),I=1,2),J=1,36)/
     $  66.37, 86.56, 65.56, 94.25, 64.97,102.09, 64.54,110.12,
     $  64.26,118.41, 64.06,126.98, 63.93,135.83, 63.81,144.93,
     $  63.69,154.24, 63.54,163.65, 63.33,173.07, 63.09,182.37,
     $  62.82,191.41, 62.58,200.10, 62.42,208.37, 62.41,216.24,
     $  62.61,223.75, 63.08,231.01, 63.84,238.15, 64.90,245.33,
     $  66.24,252.73, 67.84,260.57, 69.65,269.16, 71.59,278.88,
     $  73.54,290.31, 75.29,303.77, 76.64,319.65, 77.37,337.64,
     $  77.33,356.38, 76.56, 13.96, 75.24, 29.23, 73.59, 42.10,
     $  71.83, 53.01, 70.17, 62.38, 68.68, 70.86, 67.41, 78.83/
C
      DATA((A(I,J, 12),I=1,2),J=1,36)/
     $  64.24, 85.03, 63.46, 92.85, 62.90,100.80, 62.52,108.97,
     $  62.27,117.42, 62.11,126.15, 62.00,135.16, 61.90,144.43,
     $  61.79,153.91, 61.63,163.51, 61.42,173.12, 61.15,182.60,
     $  60.84,191.83, 60.55,200.69, 60.34,209.12, 60.29,217.11,
     $  60.46,224.74, 60.92,232.11, 61.69,239.36, 62.77,246.67,
     $  64.16,254.20, 65.82,262.18, 67.67,270.87, 69.66,280.68,
     $  71.65,292.02, 73.45,305.47, 74.81,320.98, 75.54,338.28,
     $  75.49,356.17, 74.69, 13.07, 73.32, 27.96, 71.60, 40.67,
     $  69.82, 51.36, 68.11, 60.72, 66.57, 69.22, 65.26, 77.22/
C
      DATA((A(I,J, 13),I=1,2),J=1,36)/
     $  62.09, 83.73, 61.34, 91.63, 60.82, 99.69, 60.48,107.99,
     $  60.27,116.57, 60.13,125.44, 60.05,134.60, 59.96,144.01,
     $  59.86,153.63, 59.70,163.38, 59.48,173.14, 59.19,182.79,
     $  58.85,192.18, 58.52,201.19, 58.26,209.75, 58.16,217.87,
     $  58.31,225.59, 58.75,233.05, 59.53,240.40, 60.65,247.81,
     $  62.07,255.46, 63.78,263.56, 65.69,272.37, 67.72,282.20,
     $  69.75,293.52, 71.58,306.71, 72.97,322.00, 73.70,338.79,
     $  73.64,356.07, 72.81, 12.49, 71.39, 27.03, 69.63, 39.40,
     $  67.77, 50.01, 65.98, 59.34, 64.41, 67.82, 63.11, 75.86/
C
      DATA((A(I,J, 14),I=1,2),J=1,36)/
     $  59.91, 82.58, 59.20, 90.55, 58.72, 98.72, 58.42,107.14,
     $  58.25,115.85, 58.14,124.86, 58.07,134.14, 58.00,143.66,
     $  57.90,153.39, 57.75,163.26, 57.52,173.15, 57.21,182.94,
     $  56.84,192.46, 56.47,201.60, 56.17,210.28, 56.03,218.48,
     $  56.15,226.30, 56.59,233.85, 57.38,241.29, 58.52,248.80,
     $  59.98,256.56, 61.72,264.76, 63.68,273.65, 65.77,283.54,
     $  67.83,294.80, 69.69,307.83, 71.12,322.74, 71.87,339.16,
     $  71.79,356.01, 70.93, 11.97, 69.45, 26.14, 67.62, 38.36,
     $  65.67, 48.90, 63.83, 58.16, 62.23, 66.62, 60.91, 74.67/
C
      DATA((A(I,J, 15),I=1,2),J=1,36)/
     $  57.69, 81.56, 57.02, 89.60, 56.59, 97.86, 56.34,106.39,
     $  56.21,115.23, 56.14,124.35, 56.09,133.75, 56.03,143.38,
     $  55.93,153.20, 55.78,163.16, 55.54,173.15, 55.22,183.05,
     $  54.82,192.69, 54.41,201.94, 54.07,210.71, 53.91,219.00,
     $  54.01,226.90, 54.45,234.53, 55.24,242.06, 56.40,249.67,
     $  57.89,257.52, 59.67,265.83, 61.67,274.79, 63.79,284.70,
     $  65.89,295.92, 67.79,308.77, 69.24,323.41, 70.00,339.43,
     $  69.92,355.85, 69.03, 11.46, 67.49, 25.41, 65.57, 37.52,
     $  63.56, 47.93, 61.65, 57.14, 60.00, 65.58, 58.68, 73.62/
C
      DATA((A(I,J, 16),I=1,2),J=1,36)/
     $  55.44, 80.65, 54.81, 88.75, 54.44, 97.09, 54.25,105.74,
     $  54.16,114.69, 54.12,123.93, 54.09,133.43, 54.03,143.14,
     $  53.94,153.04, 53.78,163.07, 53.54,173.14, 53.21,183.12,
     $  52.79,192.86, 52.35,202.20, 51.98,211.06, 51.79,219.43,
     $  51.88,227.40, 52.32,235.11, 53.13,242.74, 54.31,250.44,
     $  55.82,258.39, 57.62,266.78, 59.64,275.81, 61.79,285.74,
     $  63.93,296.90, 65.86,309.60, 67.34,323.96, 68.12,339.65,
     $  68.04,355.72, 67.11, 11.05, 65.50, 24.83, 63.51, 36.76,
     $  61.41, 47.09, 59.43, 56.24, 57.73, 64.64, 56.39, 72.68/
C
      DATA((A(I,J, 17),I=1,2),J=1,36)/
     $  53.14, 79.83, 52.56, 87.98, 52.26, 96.41, 52.14,105.16,
     $  52.10,114.22, 52.10,123.57, 52.07,133.17, 52.02,142.96,
     $  51.92,152.92, 51.77,162.99, 51.53,173.12, 51.18,183.17,
     $  50.75,192.99, 50.28,202.41, 49.88,211.35, 49.67,219.79,
     $  49.75,227.83, 50.20,235.61, 51.04,243.32, 52.23,251.13,
     $  53.76,259.18, 55.58,267.65, 57.62,276.74, 59.79,286.68,
     $  61.95,297.78, 63.92,310.33, 65.43,324.45, 66.23,339.83,
     $  66.15,355.61, 65.18, 10.71, 63.51, 24.29, 61.43, 36.11,
     $  59.23, 46.36, 57.16, 55.45, 55.41, 63.82, 54.07, 71.85/
C
      DATA((A(I,J, 18),I=1,2),J=1,36)/
     $  50.78, 79.09, 50.27, 87.29, 50.05, 95.79, 50.00,104.64,
     $  50.03,113.81, 50.06,123.27, 50.05,132.96, 50.00,142.82,
     $  49.89,152.81, 49.73,162.92, 49.49,173.08, 49.15,183.19,
     $  48.70,193.07, 48.22,202.57, 47.79,211.57, 47.56,220.08,
     $  47.64,228.18, 48.10,236.04, 48.96,243.84, 50.19,251.75,
     $  51.73,259.90, 53.55,268.46, 55.60,277.59, 57.78,287.54,
     $  59.96,298.57, 61.95,310.98, 63.50,324.88, 64.32,339.98,
     $  64.24,355.50, 63.24, 10.39, 61.50, 23.83, 59.32, 35.55,
     $  57.01, 45.73, 54.85, 54.76, 53.05, 63.08, 51.69, 71.09/
C
      DATA((A(I,J, 19),I=1,2),J=1,36)/
     $  48.39, 78.42, 47.95, 86.66, 47.81, 95.24, 47.85,104.18,
     $  47.94,113.46, 48.01,123.02, 48.01,132.79, 47.95,142.71,
     $  47.84,152.73, 47.68,162.86, 47.44,173.04, 47.10,183.18,
     $  46.65,193.12, 46.14,202.68, 45.70,211.74, 45.46,220.31,
     $  45.55,228.48, 46.03,236.42, 46.91,244.31, 48.16,252.32,
     $  49.72,260.57, 51.55,269.22, 53.58,278.40, 55.76,288.34,
     $  57.96,299.31, 59.98,311.56, 61.55,325.25, 62.40,340.11,
     $  62.32,355.39, 61.29, 10.10, 59.48, 23.41, 57.19, 35.06,
     $  54.76, 45.18, 52.50, 54.14, 50.62, 62.42, 49.25, 70.41/
C
      DATA((A(I,J, 20),I=1,2),J=1,36)/
     $  45.94, 77.81, 45.58, 86.09, 45.54, 94.73, 45.67,103.77,
     $  45.84,113.15, 45.95,122.82, 45.96,132.67, 45.90,142.63,
     $  45.77,152.68, 45.60,162.80, 45.37,172.99, 45.04,183.15,
     $  44.59,193.13, 44.07,202.75, 43.61,211.87, 43.37,220.49,
     $  43.47,228.72, 43.97,236.74, 44.89,244.73, 46.15,252.84,
     $  47.73,261.20, 49.55,269.93, 51.58,279.16, 53.75,289.09,
     $  55.95,299.99, 57.98,312.10, 59.58,325.58, 60.46,340.20,
     $  60.39,355.28, 59.33,  9.83, 57.44, 23.06, 55.04, 34.63,
     $  52.48, 44.68, 50.10, 53.60, 48.14, 61.82, 46.76, 69.79/
C
      DATA((A(I,J, 21),I=1,2),J=1,36)/
     $  43.43, 77.25, 43.16, 85.57, 43.24, 94.28, 43.47,103.40,
     $  43.72,112.88, 43.88,122.65, 43.91,132.58, 43.83,142.58,
     $  43.69,152.63, 43.51,162.75, 43.29,172.93, 42.97,183.10,
     $  42.52,193.12, 42.00,202.78, 41.53,211.95, 41.28,220.62,
     $  41.40,228.92, 41.94,237.02, 42.89,245.11, 44.18,253.33,
     $  45.76,261.80, 47.57,270.61, 49.59,279.89, 51.74,289.81,
     $  53.93,300.62, 55.98,312.59, 57.60,325.87, 58.52,340.27,
     $  58.46,355.16, 57.37,  9.58, 55.40, 22.73, 52.87, 34.24,
     $  50.16, 44.24, 47.64, 53.10, 45.60, 61.28, 44.20, 69.22/
C
      DATA((A(I,J, 22),I=1,2),J=1,36)/
     $  40.86, 76.74, 40.71, 85.10, 40.90, 93.88, 41.25,103.08,
     $  41.59,112.66, 41.80,122.52, 41.84,132.51, 41.75,142.55,
     $  41.59,152.60, 41.41,162.70, 41.19,172.86, 40.89,183.04,
     $  40.45,193.08, 39.93,202.78, 39.45,212.00, 39.21,220.73,
     $  39.35,229.08, 39.93,237.26, 40.91,245.45, 42.23,253.79,
     $  43.81,262.37, 45.61,271.26, 47.60,280.58, 49.73,290.49,
     $  51.91,301.23, 53.96,313.05, 55.62,326.13, 56.56,340.33,
     $  56.52,355.04, 55.41,  9.35, 53.35, 22.43, 50.68, 33.90,
     $  47.81, 43.85, 45.14, 52.66, 43.00, 60.79, 41.58, 68.71/
C
      DATA((A(I,J, 23),I=1,2),J=1,36)/
     $  38.23, 76.27, 38.20, 84.67, 38.53, 93.51, 39.01,102.80,
     $  39.45,112.47, 39.71,122.41, 39.76,132.47, 39.65,142.54,
     $  39.48,152.59, 39.29,162.65, 39.09,172.79, 38.80,182.96,
     $  38.38,193.02, 37.86,202.75, 37.38,212.02, 37.15,220.79,
     $  37.31,229.21, 37.94,237.47, 38.97,245.76, 40.31,254.22,
     $  41.89,262.91, 43.66,271.88, 45.62,281.24, 47.72,291.15,
     $  49.89,301.81, 51.94,313.49, 53.63,326.38, 54.61,340.37,
     $  54.58,354.92, 53.44,  9.12, 51.30, 22.15, 48.48, 33.58,
     $  45.42, 43.50, 42.58, 52.25, 40.33, 60.34, 38.89, 68.23/
C
      DATA((A(I,J, 24),I=1,2),J=1,36)/
     $  35.52, 75.85, 35.63, 84.29, 36.12, 93.19, 36.74,102.55,
     $  37.29,112.30, 37.61,122.33, 37.68,132.45, 37.55,142.54,
     $  37.35,152.58, 37.16,162.61, 36.97,172.72, 36.70,182.88,
     $  36.30,192.94, 35.78,202.70, 35.31,212.00, 35.09,220.83,
     $  35.29,229.31, 35.97,237.66, 37.05,246.06, 38.42,254.63,
     $  39.99,263.43, 41.73,272.49, 43.65,281.88, 45.72,291.78,
     $  47.86,302.36, 49.92,313.90, 51.63,326.60, 52.64,340.40,
     $  52.64,354.80, 51.48,  8.91, 49.25, 21.88, 46.27, 33.29,
     $  43.01, 43.17, 39.96, 51.88, 37.57, 59.92, 36.10, 67.79/
C
      DATA((A(I,J, 25),I=1,2),J=1,36)/
     $  32.74, 75.46, 33.00, 83.95, 33.66, 92.90, 34.44,102.33,
     $  35.11,112.16, 35.50,122.26, 35.58,132.44, 35.44,142.55,
     $  35.21,152.57, 35.01,162.58, 34.84,172.65, 34.60,182.78,
     $  34.22,192.85, 33.71,202.63, 33.25,211.97, 33.04,220.85,
     $  33.29,229.39, 34.02,237.82, 35.16,246.33, 36.55,255.02,
     $  38.12,263.93, 39.82,273.07, 41.69,282.51, 43.72,292.38,
     $  45.83,302.90, 47.88,314.30, 49.62,326.81, 50.68,340.42,
     $  50.70,354.66, 49.52,  8.69, 47.19, 21.63, 44.05, 33.02,
     $  40.55, 42.87, 37.27, 51.54, 34.73, 59.54, 33.22, 67.39/
C
      DATA((A(I,J, 26),I=1,2),J=1,36)/
     $  29.86, 75.11, 30.30, 83.64, 31.15, 92.65, 32.12,102.14,
     $  32.92,112.04, 33.38,122.21, 33.48,132.44, 33.31,142.57,
     $  33.06,152.57, 32.86,162.54, 32.70,172.57, 32.49,182.68,
     $  32.13,192.75, 31.64,202.55, 31.18,211.92, 31.00,220.85,
     $  31.29,229.46, 32.09,237.98, 33.28,246.60, 34.71,255.41,
     $  36.26,264.42, 37.93,273.64, 39.74,283.12, 41.72,292.98,
     $  43.80,303.42, 45.84,314.69, 47.60,327.01, 48.70,340.43,
     $  48.77,354.52, 47.57,  8.46, 45.15, 21.38, 41.81, 32.76,
     $  38.06, 42.59, 34.51, 51.22, 31.77, 59.19, 30.41, 67.02/
C
      DATA((A(I,J, 27),I=1,2),J=1,36)/
     $  26.98, 74.80, 27.56, 83.38, 28.59, 92.44, 29.75,101.98,
     $  30.70,111.94, 31.25,122.18, 31.36,132.45, 31.18,142.59,
     $  30.90,152.58, 30.69,162.50, 30.55,172.50, 30.37,182.58,
     $  30.04,192.64, 29.56,202.46, 29.12,211.86, 28.97,220.83,
     $  29.31,229.52, 30.18,238.12, 31.43,246.85, 32.88,255.78,
     $  34.42,264.90, 36.04,274.20, 37.81,283.71, 39.72,293.55,
     $  41.76,303.93, 43.80,315.06, 45.57,327.21, 46.72,340.43,
     $  46.83,354.37, 45.62,  8.23, 43.10, 21.13, 39.57, 32.51,
     $  35.76, 42.32, 31.66, 50.93, 28.98, 58.86, 27.49, 66.68/
C
      DATA((A(I,J, 28),I=1,2),J=1,36)/
     $  24.17, 74.52, 24.88, 83.15, 25.97, 92.26, 27.35,101.85,
     $  28.47,111.87, 29.11,122.15, 29.24,132.46, 29.03,142.61,
     $  28.73,152.58, 28.51,162.47, 28.39,172.42, 28.24,182.48,
     $  27.94,192.53, 27.48,202.35, 27.06,211.79, 26.93,220.82,
     $  27.33,229.57, 28.27,238.26, 29.59,247.10, 31.07,256.14,
     $  32.59,265.37, 34.17,274.74, 35.87,284.28, 37.73,294.12,
     $  39.73,304.42, 41.74,315.43, 43.54,327.40, 44.74,340.43,
     $  44.89,354.21, 43.68,  8.00, 41.07, 20.88, 37.32, 32.26,
     $  33.47, 42.07, 29.05, 50.65, 26.07, 58.55, 24.45, 66.38/
C
      DATA((A(I,J, 29),I=1,2),J=1,36)/
     $  21.44, 74.28, 22.27, 82.96, 23.41, 92.11, 24.88,101.74,
     $  26.22,111.81, 26.95,122.14, 27.10,132.47, 26.87,142.63,
     $  26.55,152.58, 26.32,162.44, 26.22,172.35, 26.10,182.38,
     $  25.84,192.41, 25.40,202.25, 24.99,211.71, 24.91,220.79,
     $  25.36,229.62, 26.38,238.40, 27.77,247.34, 29.27,256.50,
     $  30.77,265.83, 32.30,275.27, 33.94,284.84, 35.74,294.67,
     $  37.69,304.91, 39.68,315.79, 41.50,327.58, 42.75,340.42,
     $  42.95,354.05, 41.75,  7.76, 39.04, 20.62, 35.06, 32.01,
     $  31.21, 41.82, 26.51, 50.38, 23.27, 58.26, 21.24, 66.08/
C
      DATA((A(I,J, 30),I=1,2),J=1,36)/
     $  18.78, 74.06, 19.72, 82.79, 20.91, 91.99, 22.46,101.65,
     $  23.96,111.76, 24.79,122.13, 24.96,132.49, 24.71,142.64,
     $  24.36,152.57, 24.12,162.41, 24.03,172.29, 23.96,182.28,
     $  23.73,192.30, 23.32,202.14, 22.93,211.64, 22.89,220.77,
     $  23.41,229.67, 24.50,238.55, 25.95,247.59, 27.49,256.86,
     $  28.96,266.28, 30.43,275.78, 32.00,285.39, 33.74,295.20,
     $  35.64,305.38, 37.61,316.15, 39.45,327.76, 40.76,340.41,
     $  41.02,353.88, 39.82,  7.51, 37.02, 20.35, 32.80, 31.75,
     $  28.97, 41.57, 24.03, 50.12, 20.56, 57.97, 18.19, 65.81/
C
      DATA((A(I,J, 31),I=1,2),J=1,36)/
     $  16.19, 73.86, 17.22, 82.66, 18.46, 91.90, 20.07,101.59,
     $  21.67,111.73, 22.62,122.13, 22.81,132.50, 22.54,142.65,
     $  22.16,152.57, 21.91,162.38, 21.84,172.22, 21.81,182.19,
     $  21.61,192.19, 21.23,202.03, 20.88,211.56, 20.88,220.75,
     $  21.46,229.73, 22.62,238.70, 24.14,247.84, 25.70,257.21,
     $  27.15,266.72, 28.56,276.28, 30.06,285.91, 31.74,295.72,
     $  33.59,305.85, 35.54,316.49, 37.40,327.94, 38.76,340.39,
     $  39.09,353.71, 37.91,  7.24, 35.01, 20.07, 30.53, 31.49,
     $  26.77, 41.32, 21.62, 49.87, 17.95, 57.71, 15.29, 65.56/
C
      DATA((A(I,J, 32),I=1,2),J=1,36)/
     $  13.67, 73.69, 14.79, 82.55, 16.07, 91.82, 17.72,101.55,
     $  19.36,111.72, 20.43,122.14, 20.65,132.51, 20.36,142.65,
     $  19.96,152.56, 19.70,162.35, 19.65,172.17, 19.65,182.10,
     $  19.49,192.08, 19.14,201.93, 18.82,211.49, 18.87,220.74,
     $  19.52,229.80, 20.76,238.86, 22.33,248.09, 23.92,257.55,
     $  25.34,267.15, 26.68,276.77, 28.12,286.42, 29.74,296.22,
     $  31.53,306.30, 33.45,316.84, 35.33,328.12, 36.75,340.38,
     $  37.15,353.53, 36.00,  6.97, 33.02, 19.77, 28.47, 31.21,
     $  24.59, 41.06, 19.27, 49.61, 15.43, 57.45, 12.53, 65.33/
C
      DATA((A(I,J, 33),I=1,2),J=1,36)/
     $  11.21, 73.53, 12.41, 82.46, 13.73, 91.78, 15.40,101.53,
     $  17.03,111.71, 18.24,122.14, 18.48,132.51, 18.18,142.64,
     $  17.75,152.54, 17.48,162.32, 17.44,172.12, 17.48,182.02,
     $  17.36,191.98, 17.04,201.83, 16.76,211.42, 16.86,220.73,
     $  17.58,229.88, 18.90,239.03, 20.53,248.36, 22.13,257.90,
     $  23.53,267.57, 24.81,277.24, 26.18,286.91, 27.73,296.71,
     $  29.47,306.74, 31.36,317.17, 33.26,328.29, 34.74,340.37,
     $  35.22,353.36, 34.10,  6.69, 31.04, 19.46, 26.42, 30.91,
     $  22.44, 40.80, 16.98, 49.35, 12.99, 57.07,  9.92, 65.07/
C
      DATA((A(I,J, 34),I=1,2),J=1,36)/
     $   8.83, 73.38, 10.08, 82.40, 11.44, 91.76, 13.12,101.52,
     $  14.67,111.73, 16.04,122.16, 16.31,132.51, 15.99,142.63,
     $  15.54,152.51, 15.25,162.29, 15.22,172.07, 15.29,181.95,
     $  15.22,191.90, 14.99,201.74, 14.70,211.36, 14.86,220.74,
     $  15.65,229.98, 17.03,239.22, 18.72,248.63, 20.33,258.25,
     $  21.69,267.98, 22.92,277.69, 24.22,287.38, 25.71,297.17,
     $  27.40,307.16, 29.26,317.51, 31.18,328.47, 32.73,340.36,
     $  33.28,353.18, 32.21,  6.40, 29.07, 19.13, 24.37, 30.59,
     $  20.31, 40.50, 14.75, 48.95, 10.64, 56.69,  7.44, 64.82/
C
      DATA((A(I,J, 35),I=1,2),J=1,36)/
     $   6.50, 73.23,  7.81, 82.33,  9.19, 91.75, 10.87,101.52,
     $  12.37,111.74, 13.82,122.18, 14.12,132.51, 13.79,142.60,
     $  13.32,152.48, 13.00,162.26, 12.99,172.03, 13.09,181.90,
     $  13.06,191.82, 12.94,201.66, 12.63,211.32, 12.85,220.77,
     $  13.72,230.10, 15.16,239.43, 16.90,248.91, 18.52,258.60,
     $  19.85,268.38, 21.01,278.13, 22.25,287.83, 23.69,297.62,
     $  25.32,307.58, 27.16,317.83, 29.09,328.66, 30.71,340.37,
     $  31.35,353.00, 30.32,  6.10, 27.12, 18.77, 22.34, 30.24,
     $  18.21, 40.18, 12.57, 48.44,  8.37, 56.31,  5.08, 64.56/
C
      DATA((A(I,J, 36),I=1,2),J=1,36)/
     $   4.24, 73.08,  5.59, 82.27,  7.00, 91.75,  8.65,101.55,
     $  10.11,111.78, 11.60,122.20, 11.92,132.49, 11.57,142.56,
     $  11.08,152.44, 10.75,162.22, 10.74,172.00, 10.96,181.85,
     $  10.94,191.75, 10.90,201.60, 10.56,211.29, 10.84,220.81,
     $  11.78,230.23, 13.28,239.65, 15.06,249.20, 16.69,258.94,
     $  17.99,268.77, 19.09,278.54, 20.28,288.26, 21.66,298.05,
     $  23.24,307.98, 25.05,318.16, 27.00,328.84, 28.68,340.37,
     $  29.41,352.83, 28.44,  5.79, 25.19, 18.40, 20.32, 29.86,
     $  16.14, 39.83, 10.45, 47.92,  6.18, 55.92,  2.86, 64.31/
C
      DATA((A(I,J, 37),I=1,2),J=1,36)/
     $   2.03, 72.92,  3.42, 82.20,  4.84, 91.76,  6.46,101.60,
     $   7.90,111.82,  9.39,122.21,  9.71,132.47,  9.35,142.52,
     $   8.83,152.40,  8.50,162.19,  8.50,171.97,  8.83,181.81,
     $   8.82,191.69,  8.87,201.54,  8.49,211.28,  8.82,220.87,
     $   9.83,230.38, 11.39,239.88, 13.21,249.49, 14.85,259.28,
     $  16.10,269.14, 17.16,278.93, 18.29,288.67, 19.63,298.46,
     $  21.16,308.37, 22.93,318.48, 24.90,329.04, 26.66,340.39,
     $  27.47,352.67, 26.56,  5.48, 23.27, 18.00, 18.31, 29.45,
     $  14.09, 39.31,  8.38, 47.40,  4.06, 55.54,  0.85, 64.05/
C
      DATA((A(I,J, 38),I=1,2),J=1,36)/
     $   0.02, 72.77,  0.98, 82.13,  2.21, 91.76,  4.30,101.64,
     $   5.72,111.87,  7.17,122.22,  7.49,132.44,  7.13,142.46,
     $   6.58,152.34,  6.26,162.15,  6.26,171.95,  6.70,181.78,
     $   6.72,191.65,  6.84,201.50,  6.41,211.28,  6.81,220.96,
     $   7.88,230.55,  9.49,240.12, 11.34,249.79, 12.99,259.62,
     $  14.19,269.50, 15.20,279.31, 16.30,289.06, 17.59,298.86,
     $  19.07,308.74, 20.82,318.79, 22.80,329.23, 24.62,340.42,
     $  25.53,352.52, 24.68,  5.16, 21.37, 17.58, 16.31, 29.00,
     $  12.06, 38.67,  6.35, 46.89,  2.60, 55.16, -0.46, 63.80/
C
      DATA((A(I,J, 39),I=1,2),J=1,36)/
     $  -1.99, 72.62, -1.46, 82.07, -0.43, 91.76,  2.11,101.69,
     $   3.54,111.91,  4.96,122.23,  5.27,132.40,  4.90,142.40,
     $   4.34,152.28,  4.09,162.11,  4.17,171.93,  4.57,181.76,
     $   4.61,191.62,  4.81,201.48,  4.32,211.30,  4.80,221.05,
     $   5.92,230.73,  7.57,240.38,  9.44,250.10, 11.09,259.95,
     $  12.27,269.85, 13.22,279.67, 14.30,289.44, 15.55,299.24,
     $  17.00,309.10, 18.70,319.10, 20.70,329.43, 22.59,340.47,
     $  23.59,352.37, 22.81,  4.84, 19.48, 17.14, 14.32, 28.51,
     $  10.06, 38.03,  4.36, 46.37,  1.14, 54.77, -1.77, 63.54/
C
      DATA((A(I,J, 40),I=1,2),J=1,36)/
     $  -3.94, 72.46, -3.83, 82.00, -3.01, 91.77, -0.08,101.74,
     $   1.35,111.94,  2.80,122.23,  3.07,132.35,  2.69,142.32,
     $   2.14,152.20,  1.93,162.06,  2.07,171.91,  2.46,181.76,
     $   2.57,191.62,  2.62,201.47,  2.32,211.34,  2.83,221.17,
     $   3.95,230.93,  5.63,240.66,  7.49,250.42,  9.17,260.28,
     $  10.32,270.18, 11.24,280.01, 12.30,289.79, 13.49,299.61,
     $  14.93,309.46, 16.58,319.40, 18.61,329.65, 20.56,340.53,
     $  21.64,352.24, 20.94,  4.52, 17.61, 16.68, 12.34, 27.98,
     $   8.08, 37.38,  2.74, 45.85, -0.22, 54.39, -3.71, 63.29/
C
      DATA((A(I,J, 41),I=1,2),J=1,36)/
     $  -5.89, 72.31, -5.99, 81.94, -5.29, 91.77, -2.24,101.78,
     $  -0.80,111.97,  0.64,122.19,  0.86,132.29,  0.48,142.21,
     $  -0.05,152.09, -0.23,161.99, -0.02,171.90,  0.35,181.77,
     $   0.53,191.63,  0.43,201.50,  0.31,211.41,  0.81,221.30,
     $   1.97,231.15,  3.70,240.94,  5.52,250.73,  7.20,260.60,
     $   8.35,270.51,  9.26,280.35, 10.28,290.14, 11.43,299.96,
     $  12.86,309.80, 14.53,319.70, 16.52,329.86, 18.53,340.61,
     $  19.68,352.13, 19.07,  4.20, 15.75, 16.21, 10.37, 27.41,
     $   6.12, 36.74,  1.11, 45.34, -1.81, 54.01, -5.55, 63.03/
C
      DATA((A(I,J, 42),I=1,2),J=1,36)/
     $  -7.85, 72.16, -8.16, 81.87, -7.56, 91.77, -4.35,101.83,
     $  -2.91,112.00, -1.51,122.15, -1.35,132.21, -1.73,142.12,
     $  -2.24,152.03, -2.43,161.96, -2.19,171.88, -1.77,181.79,
     $  -1.52,191.65, -1.77,201.54, -1.70,211.47, -1.22,221.45,
     $  -0.02,231.39,  1.74,241.23,  3.61,251.06,  5.20,260.93,
     $   6.37,270.83,  7.26,280.67,  8.26,290.47,  9.37,300.30,
     $  10.80,310.14, 12.48,320.00, 14.43,330.09, 16.49,340.70,
     $  17.72,352.03, 17.18,  3.89, 13.90, 15.71,  8.41, 26.81,
     $   4.09, 36.10, -0.11, 44.82, -3.41, 53.63, -7.39, 62.78/
C
      DATA((A(I,J, 43),I=1,2),J=1,36)/
     $  -9.76, 72.01,-10.09, 81.81, -9.50, 91.78, -6.46,101.88,
     $  -5.02,112.03, -3.69,122.17, -3.57,132.11, -3.94,142.00,
     $  -4.45,151.92, -4.62,161.89, -4.35,171.87, -3.91,181.78,
     $  -3.61,191.62, -3.90,201.53, -3.77,211.55, -3.25,221.62,
     $  -2.02,231.62, -0.24,241.54,  1.70,251.38,  3.24,261.25,
     $   4.35,271.14,  5.25,280.99,  6.22,290.80,  7.31,300.63,
     $   8.73,310.46, 10.43,320.30, 12.36,330.33, 14.47,340.82,
     $  15.75,351.95, 15.29,  3.58, 12.04, 15.20,  6.46, 26.15,
     $   2.07, 35.45, -1.51, 44.30, -5.20, 53.24, -9.06, 62.52/
C
      DATA((A(I,J, 44),I=1,2),J=1,36)/
     $ -11.62, 71.85,-11.98, 81.74,-11.41, 91.78, -8.51,101.97,
     $  -7.09,112.12, -5.86,122.12, -5.79,132.00, -6.16,141.86,
     $  -6.66,151.80, -6.84,161.82, -6.57,171.86, -6.05,181.80,
     $  -5.71,191.65, -6.03,201.57, -5.83,211.66, -5.30,221.80,
     $  -4.04,231.87, -2.24,241.84, -0.25,251.72,  1.28,261.57,
     $   2.32,271.45,  3.25,281.31,  4.18,291.13,  5.24,300.96,
     $   6.67,310.79,  8.38,320.60, 10.29,330.57, 12.45,340.95,
     $  13.74,351.88, 13.39,  3.28, 10.19, 14.69,  4.54, 25.46,
     $   0.69, 34.81, -2.90, 43.79, -6.95, 52.86,-10.68, 62.27/
C
      DATA((A(I,J, 45),I=1,2),J=1,36)/
     $ -13.46, 71.70,-13.83, 81.68,-13.29, 91.81,-10.56,101.99,
     $  -9.16,112.12, -8.05,122.04, -8.03,131.86, -8.39,141.70,
     $  -8.88,151.66, -9.05,161.73, -8.80,171.84, -8.23,181.81,
     $  -7.87,191.68, -8.10,201.64, -7.95,211.77, -7.37,221.99,
     $  -6.07,232.14, -4.27,242.15, -2.27,252.05, -0.73,261.89,
     $   0.28,271.76,  1.25,281.63,  2.27,291.46,  3.39,301.29,
     $   4.61,311.11,  6.34,320.91,  8.13,330.83, 10.42,341.10,
     $  11.72,351.84, 11.48,  2.99,  8.34, 14.16,  3.03, 24.77,
     $  -0.59, 34.17, -4.65, 43.27, -8.68, 52.48,-12.26, 62.01/
C
      DATA((A(I,J, 46),I=1,2),J=1,36)/
     $ -15.25, 71.55,-15.66, 81.61,-15.15, 91.76,-12.59,101.99,
     $ -11.23,112.08,-10.24,121.94,-10.27,131.70,-10.61,141.52,
     $ -11.09,151.50,-11.27,161.63,-11.02,171.81,-10.41,181.83,
     $ -10.05,191.73,-10.18,201.71,-10.08,211.90, -9.45,222.19,
     $  -8.13,232.41, -6.31,242.48, -4.30,252.38, -2.79,262.22,
     $  -1.78,272.08, -0.77,281.95,  0.37,291.80,  1.53,301.62,
     $   2.74,311.43,  4.30,321.23,  5.99,331.11,  8.36,341.26,
     $   9.71,351.82,  9.53,  2.72,  6.48, 13.64,  1.52, 24.08,
     $  -1.87, 33.52, -6.40, 42.75,-10.36, 52.10,-13.81, 61.76/
C
      DATA((A(I,J, 47),I=1,2),J=1,36)/
     $ -17.01, 71.40,-17.46, 81.45,-16.99, 91.68,-14.62,101.95,
     $ -13.32,112.01,-12.50,121.80,-12.49,131.50,-12.84,141.31,
     $ -13.30,151.31,-13.52,161.52,-13.24,171.77,-12.62,181.85,
     $ -12.24,191.78,-12.29,201.79,-12.21,212.05,-11.54,222.41,
     $ -10.21,232.69, -8.40,242.80, -6.42,252.73, -4.86,262.56,
     $  -3.86,272.41, -2.80,282.28, -1.54,292.13, -0.32,301.96,
     $   0.87,311.77,  2.37,321.55,  3.86,331.39,  6.32,341.44,
     $   7.71,351.81,  7.59,  2.46,  4.63, 13.11,  0.17, 23.39,
     $  -3.57, 32.88, -8.14, 42.24,-12.03, 51.71,-15.33, 61.50/
C
      DATA((A(I,J, 48),I=1,2),J=1,36)/
     $ -18.74, 71.08,-19.24, 81.24,-18.81, 91.57,-16.64,101.88,
     $ -15.41,111.90,-14.75,121.63,-14.70,131.28,-15.05,141.07,
     $ -15.54,151.10,-15.77,161.39,-15.49,171.71,-14.90,181.86,
     $ -14.50,191.83,-14.46,201.89,-14.34,212.20,-13.64,222.63,
     $ -12.30,232.98,-10.50,243.14, -8.57,253.08, -7.00,262.90,
     $  -5.94,272.75, -4.84,282.63, -3.52,292.48, -2.26,302.30,
     $  -0.99,312.10,  0.44,321.90,  1.99,331.69,  4.30,341.64,
     $   5.72,351.83,  5.65,  2.21,  2.88, 12.60, -1.34, 22.69,
     $  -5.37, 32.24, -9.88, 41.72,-13.67, 51.33,-16.83, 61.14/
C
      DATA((A(I,J, 49),I=1,2),J=1,36)/
     $ -20.44, 70.71,-20.99, 81.00,-20.61, 91.42,-18.66,101.75,
     $ -17.53,111.74,-16.97,121.42,-16.91,131.02,-17.27,140.79,
     $ -17.77,150.87,-18.01,161.23,-17.75,171.64,-17.18,181.86,
     $ -16.76,191.89,-16.66,202.00,-16.48,212.36,-15.75,222.87,
     $ -14.40,233.28,-12.62,243.48,-10.72,253.45, -9.17,263.27,
     $  -8.04,273.11, -6.90,282.99, -5.50,292.85, -4.20,302.65,
     $  -2.93,312.44, -1.48,322.23,  0.12,332.02,  2.34,341.86,
     $   3.73,351.86,  3.71,  1.99,  1.13, 12.10, -2.85, 22.00,
     $  -7.18, 31.59,-11.60, 41.20,-15.29, 50.81,-18.32, 60.64/
C
      DATA((A(I,J, 50),I=1,2),J=1,36)/
     $ -22.11, 70.30,-22.71, 80.71,-22.39, 91.22,-20.67,101.57,
     $ -19.67,111.52,-19.17,121.15,-19.11,130.71,-19.49,140.48,
     $ -20.00,150.60,-20.25,161.04,-20.01,171.54,-19.45,181.84,
     $ -19.02,191.94,-18.86,202.11,-18.63,212.54,-17.88,223.11,
     $ -16.52,233.59,-14.75,243.83,-12.88,253.82,-11.32,263.64,
     $ -10.14,273.48, -8.97,283.37, -7.55,293.23, -6.23,303.02,
     $  -4.87,312.80, -3.44,322.57, -1.72,332.32,  0.39,342.13,
     $   1.87,351.91,  1.88,  1.78, -0.61, 11.63, -4.60, 21.31,
     $  -8.98, 30.88,-13.30, 40.43,-16.89, 50.14,-19.80, 60.10/
C
      DATA((A(I,J, 51),I=1,2),J=1,36)/
     $ -23.75, 69.85,-24.41, 80.38,-24.17, 90.97,-22.68,101.33,
     $ -21.85,111.25,-21.35,120.82,-21.30,130.35,-21.69,140.13,
     $ -22.22,150.30,-22.48,160.83,-22.26,171.42,-21.73,181.82,
     $ -21.29,192.00,-21.08,202.24,-20.79,212.73,-20.01,223.37,
     $ -18.65,233.92,-16.89,244.20,-15.06,254.21,-13.47,264.04,
     $ -12.24,273.88,-11.03,283.78, -9.60,293.63, -8.26,303.41,
     $  -6.88,313.17, -5.40,322.94, -3.65,332.66, -1.54,342.33,
     $   0.00,352.06,  0.04,  1.68, -2.42, 11.14, -6.40, 20.63,
     $ -10.77, 30.09,-15.00, 39.65,-18.48, 49.45,-21.28, 59.53/
C
      DATA((A(I,J, 52),I=1,2),J=1,36)/
     $ -25.37, 69.36,-26.10, 80.00,-25.92, 90.65,-24.69,101.02,
     $ -23.98,110.90,-23.50,120.43,-23.48,129.94,-23.89,139.73,
     $ -24.43,149.96,-24.70,160.58,-24.51,171.28,-24.01,181.77,
     $ -23.55,192.04,-23.30,202.36,-22.95,212.93,-22.15,223.64,
     $ -20.79,234.25,-19.05,244.58,-17.23,254.61,-15.64,264.47,
     $ -14.35,274.31,-13.09,284.21,-11.64,294.05,-10.28,303.82,
     $  -8.90,313.57, -7.40,323.32, -5.58,333.01, -3.47,342.59,
     $  -1.85,352.09, -1.79,  1.46, -4.22, 10.71, -8.23, 19.97,
     $ -12.54, 29.32,-16.68, 38.88,-20.05, 48.74,-22.77, 58.92/
C
      DATA((A(I,J, 53),I=1,2),J=1,36)/
     $ -26.97, 68.83,-27.76, 79.56,-27.67, 90.27,-26.69,100.63,
     $ -26.07,110.49,-25.62,119.98,-25.64,129.47,-26.07,139.29,
     $ -26.63,149.58,-26.92,160.29,-26.76,171.10,-26.28,181.71,
     $ -25.83,192.09,-25.52,202.50,-25.13,213.14,-24.31,223.93,
     $ -22.94,234.60,-21.22,244.97,-19.42,255.04,-17.81,264.92,
     $ -16.46,274.77,-15.15,284.66,-13.68,294.50,-12.29,304.25,
     $ -10.91,313.99, -9.39,323.72, -7.56,333.37, -5.40,342.87,
     $  -3.74,352.17, -3.67,  1.28, -6.09, 10.29,-10.02, 19.34,
     $ -14.28, 28.58,-18.34, 38.11,-21.61, 48.02,-24.27, 58.28/
C
      DATA((A(I,J, 54),I=1,2),J=1,36)/
     $ -28.54, 68.26,-29.40, 79.07,-29.40, 89.82,-28.69,100.18,
     $ -28.11,109.99,-27.71,119.46,-27.77,128.95,-28.24,138.79,
     $ -28.81,149.16,-29.13,159.96,-29.01,170.88,-28.56,181.62,
     $ -28.10,192.12,-27.76,202.63,-27.32,213.36,-26.48,224.22,
     $ -25.11,234.96,-23.39,245.39,-21.60,255.50,-19.97,265.40,
     $ -18.56,275.26,-17.20,285.14,-15.71,294.97,-14.27,304.71,
     $ -12.89,314.43,-11.36,324.14, -9.49,333.76, -7.32,343.16,
     $  -5.64,352.28, -5.55,  1.16, -7.97,  9.91,-11.80, 18.75,
     $ -15.99, 27.86,-19.99, 37.36,-23.15, 47.30,-25.78, 57.63/
C
      DATA((A(I,J, 55),I=1,2),J=1,36)/
     $ -30.09, 67.65,-31.02, 78.53,-31.11, 89.30,-30.63, 99.64,
     $ -30.11,109.43,-29.77,118.87,-29.88,128.36,-30.38,138.24,
     $ -30.99,148.68,-31.33,159.58,-31.25,170.63,-30.84,181.51,
     $ -30.38,192.15,-30.00,202.78,-29.52,213.59,-28.65,224.54,
     $ -27.28,235.35,-25.57,245.83,-23.78,255.98,-22.13,265.91,
     $ -20.67,275.78,-19.24,285.65,-17.72,295.48,-16.25,305.21,
     $ -14.82,314.90,-13.28,324.59,-11.39,334.16, -9.25,343.46,
     $  -7.57,352.42, -7.48,  1.06, -9.80,  9.56,-13.55, 18.19,
     $ -17.68, 27.18,-21.62, 36.63,-24.66, 46.58,-27.30, 56.96/
C
      DATA((A(I,J, 56),I=1,2),J=1,36)/
     $ -31.61, 67.02,-32.61, 77.94,-32.80, 88.72,-32.50, 99.03,
     $ -32.05,108.78,-31.79,118.20,-31.96,127.70,-32.51,137.63,
     $ -33.14,148.15,-33.53,159.16,-33.49,170.34,-33.12,181.36,
     $ -32.66,192.16,-32.24,202.92,-31.71,213.84,-30.82,224.87,
     $ -29.45,235.76,-27.75,246.30,-25.96,256.49,-24.28,266.45,
     $ -22.76,276.33,-21.28,286.20,-19.73,296.02,-18.21,305.73,
     $ -16.74,315.40,-15.17,325.05,-13.27,334.58,-11.16,343.78,
     $  -9.50,352.58, -9.41,  0.99,-11.62,  9.25,-15.29, 17.68,
     $ -19.36, 26.53,-23.24, 35.93,-26.48, 45.88,-29.14, 56.28/
C
      DATA((A(I,J, 57),I=1,2),J=1,36)/
     $ -33.11, 66.37,-34.18, 77.30,-34.46, 88.06,-34.31, 98.34,
     $ -33.93,108.05,-33.76,117.47,-34.01,126.99,-34.60,136.96,
     $ -35.28,147.56,-35.71,158.69,-35.72,170.01,-35.39,181.19,
     $ -34.94,192.15,-34.49,203.07,-33.92,214.10,-32.99,225.22,
     $ -31.62,236.18,-29.93,246.80,-28.13,257.03,-26.42,267.03,
     $ -24.84,276.92,-23.30,286.79,-21.73,296.59,-20.16,306.28,
     $ -18.64,315.93,-17.04,325.55,-15.15,335.01,-13.06,344.12,
     $ -11.41,352.75,-11.33,  0.94,-13.44,  8.97,-17.01, 17.21,
     $ -21.04, 25.93,-24.87, 35.27,-28.19, 45.19,-30.86, 55.60/
C
      DATA((A(I,J, 58),I=1,2),J=1,36)/
     $ -34.58, 65.69,-35.72, 76.61,-36.14, 87.34,-36.04, 97.57,
     $ -35.77,107.25,-35.69,116.66,-36.02,126.20,-36.68,136.23,
     $ -37.40,146.92,-37.88,158.16,-37.94,169.63,-37.65,180.99,
     $ -37.22,192.13,-36.75,203.21,-36.12,214.38,-35.16,225.60,
     $ -33.79,236.64,-32.10,247.32,-30.29,257.61,-28.56,267.64,
     $ -26.92,277.55,-25.32,287.41,-23.70,297.19,-22.10,306.87,
     $ -20.54,316.49,-18.90,326.07,-17.01,335.47,-14.95,344.47,
     $ -13.35,352.93,-13.25,  0.93,-15.24,  8.74,-18.72, 16.79,
     $ -22.68, 25.38,-26.49, 34.64,-29.81, 44.52,-32.49, 54.92/
C
      DATA((A(I,J, 59),I=1,2),J=1,36)/
     $ -36.03, 65.00,-37.23, 75.89,-37.74, 86.56,-37.72, 96.73,
     $ -37.55,106.38,-37.58,115.78,-38.00,125.35,-38.72,135.44,
     $ -39.50,146.21,-40.03,157.58,-40.15,169.21,-39.92,180.75,
     $ -39.50,192.10,-39.00,203.36,-38.33,214.67,-37.34,226.00,
     $ -35.95,237.12,-34.26,247.88,-32.45,258.23,-30.67,268.30,
     $ -28.98,278.23,-27.33,288.08,-25.66,297.83,-24.03,307.49,
     $ -22.43,317.08,-20.75,326.62,-18.85,335.95,-16.82,344.84,
     $ -15.27,353.14,-15.16,  0.93,-17.05,  8.54,-20.40, 16.41,
     $ -24.28, 24.88,-28.05, 34.05,-31.34, 43.88,-34.02, 54.25/
C
      DATA((A(I,J, 60),I=1,2),J=1,36)/
     $ -37.46, 64.30,-38.71, 75.13,-39.27, 85.73,-39.34, 95.83,
     $ -39.28,105.44,-39.43,114.83,-39.94,124.43,-40.74,134.58,
     $ -41.57,145.44,-42.17,156.93,-42.35,168.73,-42.17,180.48,
     $ -41.77,192.04,-41.25,203.50,-40.55,214.98,-39.52,226.42,
     $ -38.12,237.64,-36.42,248.48,-34.59,258.89,-32.78,269.00,
     $ -31.04,278.94,-29.33,288.78,-27.62,298.52,-25.94,308.15,
     $ -24.30,317.71,-22.59,327.20,-20.67,336.45,-18.68,345.22,
     $ -17.18,353.36,-17.08,  0.96,-18.85,  8.38,-22.07, 16.09,
     $ -25.85, 24.42,-29.55, 33.50,-32.81, 43.27,-35.48, 53.59/
C
      DATA((A(I,J, 61),I=1,2),J=1,36)/
     $ -38.85, 63.59,-40.12, 74.33,-40.73, 84.84,-40.90, 94.86,
     $ -40.96,104.42,-41.23,113.82,-41.84,123.44,-42.72,133.65,
     $ -43.63,144.61,-44.29,156.23,-44.55,168.20,-44.42,180.17,
     $ -44.05,191.97,-43.51,203.64,-42.76,215.30,-41.70,226.88,
     $ -40.28,238.20,-38.57,249.12,-36.72,259.60,-34.87,269.75,
     $ -33.08,279.70,-31.32,289.53,-29.57,299.24,-27.85,308.85,
     $ -26.17,318.38,-24.41,327.81,-22.49,336.97,-20.53,345.61,
     $ -19.09,353.59,-18.98,  1.02,-20.65,  8.27,-23.72, 15.82,
     $ -27.39, 24.02,-31.01, 32.99,-34.22, 42.69,-36.87, 52.95/
C
      DATA((A(I,J, 62),I=1,2),J=1,36)/
     $ -40.17, 62.87,-41.46, 73.51,-42.13, 83.90,-42.40, 93.84,
     $ -42.59,103.35,-42.99,112.73,-43.71,122.38,-44.67,132.65,
     $ -45.66,143.70,-46.39,155.46,-46.73,167.61,-46.66,179.82,
     $ -46.32,191.87,-45.76,203.79,-44.98,215.64,-43.88,227.37,
     $ -42.43,238.81,-40.71,249.81,-38.84,260.36,-36.95,270.55,
     $ -35.11,280.51,-33.29,290.33,-31.50,300.02,-29.75,309.59,
     $ -28.02,319.08,-26.22,328.44,-24.29,337.51,-22.36,346.02,
     $ -20.98,353.85,-20.87,  1.11,-22.44,  8.19,-25.37, 15.59,
     $ -28.90, 23.66,-32.43, 32.53,-35.59, 42.13,-38.20, 52.31/
C
      DATA((A(I,J, 63),I=1,2),J=1,36)/
     $ -41.44, 62.14,-42.75, 72.65,-43.48, 82.93,-43.86, 92.76,
     $ -44.18,102.21,-44.71,111.58,-45.54,121.25,-46.60,131.58,
     $ -47.66,142.72,-48.48,154.61,-48.90,166.97,-48.90,179.42,
     $ -48.58,191.76,-48.02,203.94,-47.20,216.01,-46.06,227.90,
     $ -44.58,239.46,-42.83,250.56,-40.94,261.17,-39.02,271.40,
     $ -37.12,281.37,-35.26,291.17,-33.43,300.83,-31.64,310.38,
     $ -29.86,319.82,-28.03,329.11,-26.08,338.07,-24.20,346.44,
     $ -22.86,354.11,-22.75,  1.22,-24.23,  8.15,-27.00, 15.41,
     $ -30.40, 23.35,-33.82, 32.11,-36.91, 41.61,-39.48, 51.69/
C
      DATA((A(I,J, 64),I=1,2),J=1,36)/
     $ -42.66, 61.40,-43.99, 71.78,-44.79, 81.91,-45.27, 91.63,
     $ -45.72,101.01,-46.38,110.35,-47.33,120.05,-48.49,130.42,
     $ -49.64,141.66,-50.55,153.69,-51.05,166.25,-51.13,178.98,
     $ -50.84,191.62,-50.27,204.09,-49.42,216.40,-48.24,228.48,
     $ -46.73,240.17,-44.95,251.37,-43.03,262.05,-41.07,272.32,
     $ -39.13,282.30,-37.22,292.08,-35.35,301.71,-33.51,311.21,
     $ -31.69,320.60,-29.82,329.81,-27.87,338.64,-26.02,346.88,
     $ -24.74,354.40,-24.63,  1.36,-26.01,  8.16,-28.63, 15.28,
     $ -31.88, 23.10,-35.19, 31.74,-38.20, 41.12,-40.72, 51.09/
C
      DATA((A(I,J, 65),I=1,2),J=1,36)/
     $ -43.84, 60.66,-45.18, 70.87,-46.05, 80.86,-46.64, 90.45,
     $ -47.22, 99.76,-48.02,109.07,-49.09,118.77,-50.35,129.19,
     $ -51.59,140.50,-52.60,152.69,-53.19,165.47,-53.34,178.48,
     $ -53.10,191.45,-52.52,204.25,-51.63,216.83,-50.41,229.10,
     $ -48.86,240.94,-47.06,252.24,-45.10,262.99,-43.10,273.29,
     $ -41.12,283.28,-39.17,293.04,-37.25,302.64,-35.37,312.09,
     $ -33.51,321.42,-31.60,330.53,-29.65,339.24,-27.84,347.33,
     $ -26.61,354.70,-26.49,  1.53,-27.78,  8.20,-30.25, 15.20,
     $ -33.34, 22.89,-36.53, 31.40,-39.46, 40.66,-41.93, 50.49/
C
      DATA((A(I,J, 66),I=1,2),J=1,36)/
     $ -44.98, 59.91,-46.35, 69.95,-47.28, 79.77,-47.98, 89.23,
     $ -48.69, 98.45,-49.61,107.72,-50.80,117.41,-52.17,127.86,
     $ -53.52,139.26,-54.62,151.59,-55.32,164.60,-55.55,177.93,
     $ -55.35,191.26,-54.77,204.41,-53.85,217.29,-52.59,229.79,
     $ -50.99,241.79,-49.15,253.20,-47.16,264.02,-45.12,274.35,
     $ -43.09,284.33,-41.10,294.07,-39.15,303.62,-37.23,313.03,
     $ -35.32,322.27,-33.38,331.28,-31.43,339.85,-29.66,347.79,
     $ -28.47,355.02,-28.35,  1.72,-29.54,  8.28,-31.86, 15.16,
     $ -34.80, 22.73,-37.86, 31.11,-40.69, 40.22,-43.10, 49.91/
C
      DATA((A(I,J, 67),I=1,2),J=1,36)/
     $ -46.11, 59.15,-47.49, 69.00,-48.48, 78.64,-49.28, 87.96,
     $ -50.12, 97.09,-51.18,106.30,-52.48,115.97,-53.96,126.44,
     $ -55.41,137.91,-56.63,150.38,-57.43,163.64,-57.74,177.31,
     $ -57.59,191.04,-57.02,204.58,-56.07,217.79,-54.76,230.54,
     $ -53.12,242.71,-51.23,254.23,-49.20,265.12,-47.12,275.48,
     $ -45.06,285.46,-43.02,295.17,-41.03,304.67,-39.07,314.01,
     $ -37.12,323.17,-35.16,332.05,-33.21,340.48,-31.48,348.27,
     $ -30.33,355.36,-30.20,  1.94,-31.31,  8.39,-33.47, 15.17,
     $ -36.25, 22.61,-39.17, 30.85,-41.90, 39.81,-44.24, 49.33/
C
      DATA((A(I,J, 68),I=1,2),J=1,36)/
     $ -47.20, 58.37,-48.60, 68.02,-49.66, 77.47,-50.56, 86.65,
     $ -51.53, 95.66,-52.70,104.80,-54.13,114.44,-55.71,124.91,
     $ -57.27,136.44,-58.60,149.06,-59.51,162.57,-59.92,176.61,
     $ -59.82,190.79,-59.26,204.77,-58.28,218.35,-56.92,231.38,
     $ -55.24,243.74,-53.31,255.37,-51.24,266.32,-49.11,276.70,
     $ -47.00,286.67,-44.93,296.34,-42.89,305.79,-40.89,315.05,
     $ -38.91,324.10,-36.93,332.85,-35.00,341.12,-33.30,348.76,
     $ -32.19,355.72,-32.06,  2.19,-33.07,  8.54,-35.09, 15.22,
     $ -37.70, 22.54,-40.48, 30.63,-43.10, 39.42,-45.37, 48.76/
C
      DATA((A(I,J, 69),I=1,2),J=1,36)/
     $ -48.29, 57.59,-49.70, 67.02,-50.82, 76.27,-51.82, 85.28,
     $ -52.90, 94.18,-54.20,103.23,-55.74,112.82,-57.43,123.27,
     $ -59.10,134.84,-60.54,147.59,-61.58,161.38,-62.09,175.83,
     $ -62.05,190.49,-61.50,204.97,-60.49,218.98,-59.08,232.31,
     $ -57.35,244.87,-55.38,256.63,-53.26,267.64,-51.09,278.03,
     $ -48.94,287.97,-46.83,297.59,-44.75,306.98,-42.71,316.14,
     $ -40.69,325.07,-38.70,333.67,-36.78,341.78,-35.13,349.26,
     $ -34.06,356.09,-33.91,  2.46,-34.84,  8.73,-36.71, 15.30,
     $ -39.16, 22.50,-41.79, 30.43,-44.29, 39.05,-46.49, 48.18/
C
      DATA((A(I,J, 70),I=1,2),J=1,36)/
     $ -49.36, 56.79,-50.78, 65.98,-51.96, 75.03,-53.06, 83.86,
     $ -54.26, 92.62,-55.67,101.58,-57.31,111.08,-59.11,121.50,
     $ -60.89,133.09,-62.46,145.97,-63.62,160.04,-64.24,174.94,
     $ -64.27,190.15,-63.73,205.19,-62.70,219.68,-61.24,233.36,
     $ -59.45,246.14,-57.43,258.02,-55.27,269.09,-53.06,279.49,
     $ -50.86,289.39,-48.71,298.95,-46.60,308.24,-44.52,317.30,
     $ -42.48,326.09,-40.47,334.52,-38.58,342.46,-36.97,349.78,
     $ -35.94,356.49,-35.77,  2.76,-36.61,  8.95,-38.33, 15.43,
     $ -40.61, 22.49,-43.09, 30.27,-45.48, 38.70,-47.59, 47.61/
C
      DATA((A(I,J, 71),I=1,2),J=1,36)/
     $ -50.43, 55.96,-51.86, 64.92,-53.10, 73.74,-54.29, 82.39,
     $ -55.59, 91.00,-57.11, 99.83,-58.86,109.24,-60.76,119.58,
     $ -62.65,131.16,-64.35,144.15,-65.64,158.52,-66.37,173.90,
     $ -66.48,189.74,-65.96,205.44,-64.90,220.48,-63.39,234.56,
     $ -61.54,247.57,-59.46,259.58,-57.25,270.69,-55.00,281.08,
     $ -52.77,290.94,-50.57,300.41,-48.43,309.59,-46.32,318.52,
     $ -44.26,327.15,-42.25,335.41,-40.38,343.16,-38.82,350.32,
     $ -37.82,356.90,-37.64,  3.09,-38.39,  9.19,-39.97, 15.58,
     $ -42.08, 22.52,-44.40, 30.13,-46.67, 38.35,-48.70, 47.03/
C
      DATA((A(I,J, 72),I=1,2),J=1,36)/
     $ -51.50, 55.12,-52.94, 63.82,-54.24, 72.41,-55.51, 80.86,
     $ -56.91, 89.29,-58.53, 97.98,-60.37,107.25,-62.37,117.49,
     $ -64.38,129.02,-66.20,142.10,-67.63,156.77,-68.48,172.70,
     $ -68.67,189.25,-68.20,205.69,-67.12,221.38,-65.53,235.94,
     $ -63.62,249.21,-61.48,261.33,-59.22,272.47,-56.93,282.83,
     $ -54.65,292.61,-52.42,301.98,-50.25,311.03,-48.12,319.81,
     $ -46.04,328.26,-44.04,336.33,-42.20,343.90,-40.68,350.89,
     $ -39.72,357.35,-39.52,  3.44,-40.19,  9.47,-41.61, 15.77,
     $ -43.56, 22.57,-45.72, 30.00,-47.86, 38.01,-49.81, 46.45/
C
      DATA((A(I,J, 73),I=1,2),J=1,36)/
     $ -52.58, 54.25,-54.03, 62.68,-55.37, 71.02,-56.73, 79.25,
     $ -58.22, 87.49,-59.92, 96.00,-61.85,105.11,-63.94,115.19,
     $ -66.06,126.63,-68.01,139.78,-69.58,154.74,-70.57,171.28,
     $ -70.86,188.69,-70.41,206.03,-69.31,222.48,-67.69,237.54,
     $ -65.69,251.10,-63.48,263.32,-61.17,274.46,-58.83,284.76,
     $ -56.51,294.44,-54.25,303.68,-52.05,312.58,-49.90,321.17,
     $ -47.81,329.43,-45.83,337.29,-44.03,344.66,-42.56,351.49,
     $ -41.62,357.82,-41.41,  3.83,-41.99,  9.78,-43.28, 15.97,
     $ -45.05, 22.64,-47.06, 29.89,-49.07, 37.66,-50.93, 45.85/
C
      DATA((A(I,J, 74),I=1,2),J=1,36)/
     $ -53.67, 53.35,-55.13, 61.50,-56.52, 69.57,-57.94, 77.56,
     $ -59.51, 85.58,-61.29, 93.89,-63.30,102.79,-65.47,112.67,
     $ -67.69,123.96,-69.77,137.11,-71.50,152.35,-72.64,169.58,
     $ -73.03,188.12,-72.61,206.54,-71.49,223.82,-69.81,239.46,
     $ -67.75,253.32,-65.46,265.61,-63.09,276.71,-60.71,286.91,
     $ -58.35,296.46,-56.06,305.53,-53.83,314.24,-51.67,322.62,
     $ -49.59,330.66,-47.63,338.30,-45.87,345.46,-44.45,352.12,
     $ -43.55,358.32,-43.31,  4.24,-43.81, 10.11,-44.95, 16.20,
     $ -46.56, 22.73,-48.41, 29.78,-50.29, 37.32,-52.06, 45.23/
C
      DATA((A(I,J, 75),I=1,2),J=1,36)/
     $ -54.78, 52.40,-56.24, 60.25,-57.67, 68.04,-59.15, 75.77,
     $ -60.78, 83.56,-62.63, 91.62,-64.71,100.27,-66.95,109.87,
     $ -69.27,120.95,-71.48,134.01,-73.38,149.44,-74.68,167.57,
     $ -75.16,187.41,-74.76,207.28,-73.59,225.62,-71.89,241.79,
     $ -69.76,255.94,-67.42,268.29,-64.98,279.27,-62.55,289.32,
     $ -60.16,298.68,-57.84,307.54,-55.60,316.02,-53.43,324.17,
     $ -51.37,331.97,-49.43,339.37,-47.72,346.31,-46.35,352.79,
     $ -45.48,358.86,-45.22,  4.68,-45.64, 10.46,-46.65, 16.45,
     $ -48.10, 22.83,-49.78, 29.67,-51.53, 36.96,-53.21, 44.59/
C
      DATA((A(I,J, 76),I=1,2),J=1,36)/
     $ -55.92, 51.41,-57.37, 58.94,-58.82, 66.43,-60.35, 73.88,
     $ -62.04, 81.39,-63.95, 89.17,-66.08, 97.50,-68.38,106.77,
     $ -70.79,117.52,-73.12,130.26,-75.18,145.96,-76.66,164.94,
     $ -77.28,186.38,-76.91,208.06,-75.68,227.78,-73.86,244.68,
     $ -71.72,259.07,-69.31,271.40,-66.83,282.23,-64.35,292.02,
     $ -61.93,301.14,-59.59,309.75,-57.34,317.96,-55.18,325.84,
     $ -53.14,333.36,-51.25,340.50,-49.59,347.22,-48.27,353.51,
     $ -47.42,359.44,-47.15,  5.15,-47.48, 10.84,-48.36, 16.71,
     $ -49.65, 22.93,-51.18, 29.55,-52.80, 36.58,-54.39, 43.91/
C
      DATA((A(I,J, 77),I=1,2),J=1,36)/
     $ -57.07, 50.35,-58.52, 57.55,-59.99, 64.72,-61.56, 71.86,
     $ -63.29, 79.07,-65.24, 86.51,-67.39, 94.45,-69.76,103.31,
     $ -72.23,113.60,-74.68,125.93,-76.91,141.63,-78.59,161.42,
     $ -79.37,184.88,-79.05,209.07,-77.75,230.56,-75.82,248.24,
     $ -73.55,262.76,-71.14,275.05,-68.61,285.63,-66.10,295.10,
     $ -63.66,303.88,-61.31,312.17,-59.06,320.07,-56.92,327.63,
     $ -54.91,334.86,-53.06,341.72,-51.46,348.19,-50.19,354.29,
     $ -49.37,  0.07,-49.08,  5.66,-49.33, 11.24,-50.09, 16.98,
     $ -51.23, 23.02,-52.61, 29.42,-54.10, 36.17,-55.60, 43.18/
C
      DATA((A(I,J, 78),I=1,2),J=1,36)/
     $ -58.26, 49.22,-59.69, 56.08,-61.17, 62.90,-62.76, 69.70,
     $ -64.52, 76.55,-66.48, 83.60,-68.67, 91.10,-71.06, 99.42,
     $ -73.56,108.97,-76.12,120.78,-78.52,136.10,-80.44,156.58,
     $ -81.44,182.65,-81.17,210.48,-79.79,234.36,-77.72,252.83,
     $ -75.34,267.29,-72.85,279.30,-70.31,289.55,-67.78,298.61,
     $ -65.34,306.95,-62.99,314.85,-60.75,322.38,-58.64,329.58,
     $ -56.67,336.48,-54.88,343.04,-53.33,349.25,-52.12,355.13,
     $ -51.33,  0.75,-51.01,  6.21,-51.20, 11.66,-51.83, 17.26,
     $ -52.83, 23.10,-54.07, 29.26,-55.43, 35.72,-56.85, 42.40/
C
      DATA((A(I,J, 79),I=1,2),J=1,36)/
     $ -59.48, 48.01,-60.88, 54.49,-62.36, 60.94,-63.96, 67.36,
     $ -65.73, 73.81,-67.69, 80.41,-69.88, 87.38,-72.28, 95.03,
     $ -74.80,103.76,-77.44,114.59,-80.00,128.96,-82.19,149.53,
     $ -83.47,179.02,-83.28,212.69,-81.75,239.92,-79.52,258.98,
     $ -77.02,273.00,-74.45,284.30,-71.91,294.12,-69.38,302.59,
     $ -66.94,310.43,-64.62,317.83,-62.41,324.91,-60.33,331.71,
     $ -58.41,338.24,-56.69,344.47,-55.21,350.40,-54.06,356.05,
     $ -53.29,  1.49,-52.96,  6.79,-53.07, 12.10,-53.60, 17.53,
     $ -54.46, 23.16,-55.56, 29.06,-56.80, 35.21,-58.12, 41.55/
C
      DATA((A(I,J, 80),I=1,2),J=1,36)/
     $ -60.72, 46.70,-62.09, 52.77,-63.55, 58.82,-65.15, 64.82,
     $ -66.89, 70.81,-68.85, 76.90,-71.03, 83.24,-73.36, 90.03,
     $ -75.90, 97.78,-78.58,107.14,-81.27,119.66,-83.74,138.86,
     $ -85.45,172.19,-85.36,216.85,-83.59,248.71,-81.16,267.46,
     $ -78.55,280.31,-75.93,290.41,-73.36,299.22,-70.86,307.15,
     $ -68.46,314.33,-66.18,321.15,-64.02,327.72,-62.00,334.06,
     $ -60.15,340.17,-58.49,346.05,-57.09,351.67,-55.99,357.07,
     $ -55.25,  2.29,-54.90,  7.42,-54.96, 12.55,-55.38, 17.79,
     $ -56.12, 23.20,-57.09, 28.82,-58.21, 34.64,-59.43, 40.63/
C
      DATA((A(I,J, 81),I=1,2),J=1,36)/
     $ -62.01, 45.25,-63.33, 50.90,-64.76, 56.49,-66.31, 62.03,
     $ -68.04, 67.51,-69.96, 73.01,-72.08, 78.61,-74.35, 84.49,
     $ -76.85, 90.91,-79.50, 98.28,-82.24,107.70,-84.95,122.32,
     $ -87.25,155.98,-87.36,227.36,-85.16,263.64,-82.53,279.35,
     $ -79.85,289.58,-77.22,297.88,-74.68,305.31,-72.22,312.37,
     $ -69.87,318.72,-67.65,324.87,-65.57,330.85,-63.63,336.67,
     $ -61.86,342.32,-60.29,347.79,-58.96,353.08,-57.91,358.20,
     $ -57.20,  3.18,-56.84,  8.10,-56.85, 13.03,-57.18, 18.04,
     $ -57.80, 23.19,-58.64, 28.52,-59.65, 34.00,-60.78, 39.60/
C
      DATA((A(I,J, 82),I=1,2),J=1,36)/
     $ -63.32, 43.65,-64.58, 48.83,-65.96, 53.94,-67.46, 58.96,
     $ -69.14, 63.87,-70.99, 68.69,-73.00, 73.47,-75.20, 78.29,
     $ -77.59, 83.13,-80.14, 88.09,-82.80, 93.28,-85.53, 99.03,
     $ -88.30,107.93,-88.89,276.75,-86.15,288.93,-83.45,295.33,
     $ -80.81,301.14,-78.25,306.80,-75.79,312.44,-73.43,318.10,
     $ -71.16,323.68,-69.04,329.02,-67.05,334.33,-65.21,339.57,
     $ -63.53,344.71,-62.06,349.74,-60.81,354.65,-59.83,359.45,
     $ -59.15,  4.16,-58.79,  8.83,-58.74, 13.52,-59.00, 18.28,
     $ -59.51, 23.16,-60.24, 28.15,-61.14, 33.25,-62.17, 38.44/
C
      DATA((A(I,J, 83),I=1,2),J=1,36)/
     $ -64.67, 41.85,-65.85, 46.53,-67.14, 51.12,-68.58, 55.56,
     $ -70.18, 59.82,-71.94, 63.89,-73.80, 67.82,-75.87, 71.41,
     $ -78.10, 74.54,-80.44, 76.87,-82.86, 77.61,-85.28, 74.21,
     $ -87.44, 55.40,-87.95,352.45,-86.09,320.50,-83.73,314.39,
     $ -81.33,314.59,-78.96,317.06,-76.66,320.60,-74.44,324.73,
     $ -72.30,329.25,-70.30,333.68,-68.44,338.22,-66.72,342.80,
     $ -65.17,347.38,-63.80,351.93,-62.64,356.42,-61.73,  0.86,
     $ -61.09,  5.25,-60.73,  9.64,-60.65, 14.04,-60.83, 18.51,
     $ -61.25, 23.05,-61.87, 27.68,-62.66, 32.38,-63.60, 37.11/
C
      DATA((A(I,J, 84),I=1,2),J=1,36)/
     $ -66.03, 39.82,-67.11, 43.96,-68.32, 47.96,-69.67, 51.77,
     $ -71.15, 55.33,-72.75, 58.63,-74.47, 61.59,-76.34, 63.93,
     $ -78.33, 65.38,-80.37, 65.39,-82.41, 62.82,-84.30, 55.01,
     $ -85.71, 37.06,-86.03,  8.09,-85.04,344.34,-83.32,332.90,
     $ -81.33,328.77,-79.27,328.27,-77.22,329.65,-75.21,332.17,
     $ -73.28,335.35,-71.43,338.86,-69.72,342.56,-68.15,346.43,
     $ -66.74,350.40,-65.50,354.40,-64.45,358.42,-63.61,  2.45,
     $ -63.02,  6.47,-62.66, 10.51,-62.55, 14.58,-62.67, 18.69,
     $ -63.01, 22.86,-63.53, 27.08,-64.22, 31.34,-65.06, 35.60/
C
      DATA((A(I,J, 85),I=1,2),J=1,36)/
     $ -67.39, 37.51,-68.37, 41.05,-69.47, 44.41,-70.69, 47.53,
     $ -72.02, 50.34,-73.43, 52.90,-74.96, 54.84,-76.59, 56.01,
     $ -78.26, 56.06,-79.94, 54.47,-81.54, 50.35,-82.90, 42.39,
     $ -83.81, 29.57,-84.03, 13.28,-83.47,358.20,-82.32,347.85,
     $ -80.83,342.07,-79.17,339.57,-77.45,339.21,-75.72,340.20,
     $ -74.03,342.11,-72.39,344.60,-70.88,347.41,-69.49,350.51,
     $ -68.24,353.80,-67.14,357.22,-66.21,  0.71,-65.47,  4.26,
     $ -64.92,  7.85,-64.59, 11.48,-64.46, 15.14,-64.53, 18.85,
     $ -64.80, 22.59,-65.23, 26.35,-65.82, 30.11,-66.54, 33.85/
C
      DATA((A(I,J, 86),I=1,2),J=1,36)/
     $ -68.78, 34.83,-69.62, 37.72,-70.58, 40.40,-71.63, 42.80,
     $ -72.75, 44.93,-73.96, 46.63,-75.25, 47.67,-76.57, 47.89,
     $ -77.91, 47.02,-79.19, 44.71,-80.35, 40.54,-81.28, 34.14,
     $ -81.87, 25.59,-82.02, 15.77,-81.69,  6.33,-80.95,358.68,
     $ -79.90,353.35,-78.67,350.17,-77.32,348.73,-75.94,348.57,
     $ -74.55,349.38,-73.19,350.86,-71.90,352.78,-70.72,355.09,
     $ -69.65,357.65,-68.71,  0.42,-67.92,  3.32,-67.28,  6.33,
     $ -66.80,  9.42,-66.50, 12.56,-66.37, 15.75,-66.40, 18.97,
     $ -66.60, 22.21,-66.94, 25.44,-67.43, 28.65,-68.04, 31.79/
C
      DATA((A(I,J, 87),I=1,2),J=1,36)/
     $ -70.16, 31.72,-70.84, 33.91,-71.62, 35.88,-72.46, 37.56,
     $ -73.35, 39.02,-74.31, 39.94,-75.30, 40.27,-76.30, 39.88,
     $ -77.27, 38.63,-78.17, 36.37,-78.95, 32.99,-79.55, 28.50,
     $ -79.92, 23.09,-80.01, 17.19,-79.81, 11.42,-79.36,  6.35,
     $ -78.68,  2.33,-77.83,359.47,-76.88,357.73,-75.85,356.95,
     $ -74.81,356.96,-73.77,357.60,-72.76,358.72,-71.81,  0.20,
     $ -70.96,  2.03,-70.21,  4.09,-69.57,  6.33,-69.05,  8.72,
     $ -68.66, 11.20,-68.40, 13.77,-68.27, 16.38,-68.28, 19.02,
     $ -68.42, 21.67,-68.69, 24.29,-69.07, 26.87,-69.56, 29.35/
C
      DATA((A(I,J, 88),I=1,2),J=1,36)/
     $ -71.51, 28.07,-72.01, 29.52,-72.55, 30.82,-73.15, 31.91,
     $ -73.79, 32.63,-74.45, 32.96,-75.12, 32.85,-75.78, 32.26,
     $ -76.40, 31.12,-76.95, 29.42,-77.41, 27.16,-77.76, 24.42,
     $ -77.96, 21.33,-78.01, 18.05,-77.90, 14.83,-77.64, 11.86,
     $ -77.25,  9.32,-76.74,  7.29,-76.14,  5.84,-75.49,  4.95,
     $ -74.80,  4.57,-74.10,  4.66,-73.41,  5.13,-72.76,  5.93,
     $ -72.15,  6.97,-71.62,  8.31,-71.15,  9.83,-70.78, 11.50,
     $ -70.49, 13.28,-70.29, 15.14,-70.19, 17.06,-70.18, 19.00,
     $ -70.28, 20.94,-70.46, 22.84,-70.73, 24.69,-71.08, 26.44/
C
      DATA((A(I,J, 89),I=1,2),J=1,36)/
     $ -72.81, 23.87,-73.08, 24.62,-73.38, 25.21,-73.70, 25.63,
     $ -74.03, 25.85,-74.37, 25.86,-74.70, 25.67,-75.02, 25.22,
     $ -75.31, 24.55,-75.57, 23.67,-75.77, 22.58,-75.92, 21.33,
     $ -76.01, 19.99,-76.03, 18.59,-75.98, 17.21,-75.86, 15.89,
     $ -75.69, 14.71,-75.46, 13.70,-75.18, 12.89,-74.87, 12.31,
     $ -74.54, 11.95,-74.20, 11.83,-73.85, 11.91,-73.51, 12.19,
     $ -73.20, 12.64,-72.91, 13.25,-72.66, 13.98,-72.44, 14.78,
     $ -72.28, 15.74,-72.17, 16.76,-72.11, 17.82,-72.10, 18.90,
     $ -72.15, 19.97,-72.25, 21.02,-72.39, 22.02,-72.58, 23.01/
C
C 
C******************************************************************* 
C  SAVE ORIGINAL INPUTS
C******************************************************************* 
      GGLAT=OLDLAT 
      GGLON=OLDLON 
C******************************************************************* 
C     REDUCE GGLAT TO THE RANGE -90 TO +90 DEGREES
C******************************************************************* 
 6000 IF(GGLAT.LE.90.) GO TO 6001
      GGLAT=180.-GGLAT
      GGLON=GGLON+180.
      GO TO 6000
 6001 IF(GGLAT.GE.-90.) GO TO 6002
      GGLAT=-180.-GGLAT
      GGLON=GGLON+180.
      GO TO 6000
 6002 CONTINUE
C***********************************************************************
C     REDUCE GGLON TO .LT. 360 DEGREES (POSITIVE OR NEGATIVE) 
C***********************************************************************
 6666 GGLON = AMOD(GGLON,360.)
C***********************************************************************
C     CHECK TO SEE IF GGLON .GT.0, IF NOT CORRECT TO BE .GT. ZERO
C***********************************************************************
      IF(GGLON .LT. 0.0)GGLON = GGLON + 360.0
      I = IFIX((90.0 - GGLAT)/2.0)
      J = IFIX(GGLON/10.) + 1
C***********************************************************************
C     CHECK TO SEE IF I IS WITHIN BOUNDS
C***********************************************************************
      IF(I.GT.0.AND.I.LT.89)GO TO 3 
C***********************************************************************
C     SET TO INTERPOLATE TO THE POLES (N OR S GEOGRAPHIC)
C***********************************************************************
      IF (J .GT. 36) J=J-36
      IF (J .LT.  1) J=J+36
      K=J+1
      IF (K .GT. 36) K=K-36
      IF (I .GT.  0) GO TO 2 
        I=0
        X1LAT=CGMNLA
        X1LON=CGMNLO
        X2LAT=A(1,J,I+1)
        X2LON=A(2,J,I+1)
        X3LAT=A(1,K,I+1)
        X3LON=A(2,K,I+1)
        X4LAT=CGMNLA
        X4LON=CGMNLO
        GO TO 5
    2 I=89
      X1LAT=A(1,J,I)
      X1LON=A(2,J,I)
      X2LAT=CGMSLA 
      X2LON=CGMSLO 
      X3LAT=CGMSLA 
      X3LON=CGMSLO 
      X4LAT=A(1,K,I)
      X4LON=A(2,K,I)
      GO TO 5
C***********************************************************************
C     STATEMENT 3... CHECK TO SEE IF J IS WITHIN BOUNDS.  IF OUT OF
C    BOUNDS, RESTORE TO IN BOUNDS 
C***********************************************************************
    3 IF(J.GT.36)J = J - 36
      IF(J.LT.1)J = J + 36
C***********************************************************************
C     FIND CGLAT AND CGLON OF THE FOUR CORNERS OF RECTENGLE WITHIN WHICH
C     AND GGLON FALL.  THE CORNERS OF THE RECTANGLE ARE X1, X2, X3, AND 
C     REFERS TO THE NORTHWESTERLY MOST POINT OF THE RECTANGLE.  THE LABE
C     IN A COUNTERCLOCKWISE MANNER.
C***********************************************************************
      X1LAT = A(1,J,I)
      X1LON = A(2,J,I)
      X2LAT = A(1,J,I+1)
      X2LON = A(2,J,I+1)
C***********************************************************************
C     CHECK TO SEE IF THE EASTERLY EDGE OF THE RECTANGLE IS WITHIN THE L
C     ARGUMENT BOUNDS OF ARRAY A. 
C***********************************************************************
      K = J + 1
      IF(K.GT.36)K = K - 36
      X3LAT = A(1,K,I+1)
      X3LON = A(2,K,I+1)
      X4LAT = A(1,K,I)
      X4LON = A(2,K,I)
C***********************************************************************
C     ELIMINATE THE DISCONTINUITIES IN THE X1, X2, X3, AND X4 LONGITUDES
C     WOULD OCCUR IF THE PRIME MERIDIAN OF THE CORRECTED GEOMAGNETIC COO
C     SYSTEM PASSED THROUGH RECTANGLE X1, X2, X3, X4. 
C***********************************************************************
5     Y = AMAX1(X1LON,X2LON,X3LON,X4LON)
      IF(ABS(Y-X1LON).GT.180.0)X1LON = X1LON + 360.0
      IF(ABS(Y-X2LON).GT.180.0)X2LON = X2LON + 360.0
      IF(ABS(Y-X3LON).GT.180.0)X3LON = X3LON + 360.0
      IF(ABS(Y-X4LON).GT.180.0)X4LON = X4LON + 360.0
C***********************************************************************
C     CALCULATE THE SOUTHERN AND THE WESTWARD BOUNDARIES (GEOGRAPHIC LAT
C     AND LONGITUDE) OF THE RECTANGLE. 
C***********************************************************************
      EGGLA = FLOAT(-2*I + 88)
      WGGLO = FLOAT(10*J - 10)
C***********************************************************************
C     CALCULATE THE COEFFICIENTS OF THE INTERPOLATION EQUATION.  THESE
C     COEFFICIENTS REPRESENT THE FRACTIONAL PART OF THE BOX THE POINT GG
C     GGLON IS FROM THE SOUTHERN AND THE WESTWARD BOUNDARIES OF THE RECT
C***********************************************************************
      ALPHA = (GGLAT - EGGLA)/2.0
      BETA = (GGLON - WGGLO)/10.
C***********************************************************************
C     NOW CALCULATE THE CORRECTED GEOMAGNETIC COORDINATES THAT CORRESPON
C     GEOGRAPHIC COORDINATES OF THE INPUT POINT (GGLAT,GGLON) 
C***********************************************************************
      CGLAT = X2LAT + ALPHA*(X1LAT - X2LAT) + BETA*(X3LAT - X2LAT) + 
     1(ALPHA*BETA)*(X4LAT + X2LAT - X1LAT - X3LAT)
      CGLON = X2LON + ALPHA*(X1LON - X2LON) + BETA*(X3LON - X2LON) + 
     1(ALPHA*BETA)*(X4LON + X2LON - X1LON - X3LON)
C***********************************************************************
C     CHECK TO DETERMINE IF THE CORRECTED GEOMAGNETIC LONGITUDE IS LESS 
C     DEGREES.  IF IT IS NOT REDUCE THE CALCULATED VALUE BY 360.0 DEGREE
C***********************************************************************
      IF(CGLON.GT.360.0)CGLON = CGLON - 360.0
    4 RETURN
      END
